==> wcpos-7.9.2-en-download.zip: wcpos-7.9.2-en/webhelp/wcpos-webhelp/navig/contents.js <==
//
//	FindinSite-CD-JS-HelpIndex database entirenetwork
//
//	Copyright (c) 2016-2022 Software AG, Darmstadt, Germany and/or Software AG USA Inc., Reston, VA, USA
//
var entirenetwork = {
    baseurls: ["../"],
    varname: "entirenetwork",
        tree: [
            { url: "about/about.htm", title: "About this Documentation",
              tree: [
                  { url: "about/document_conventions.htm", title: "Document Conventions" },
                  { url: "about/online_information.htm", title: "Online Information and Support" },
                  { url: "about/data_protection.htm", title: "Data Protection" },
              ]
            },
            { url: "relnotes/wcporeln.htm", title: "Entire Net-Work 7.9 Release Notes",
              tree: [
                  { url: "relnotes/enhance.htm", title: "Enhancements" },
                  { url: "relnotes/wcprcomp.htm", title: "Entire Net-Work 7 Compatibility" },
                  { url: "relnotes/endofmaint.htm", title: "End of Maintenance" },
                  { url: "relnotes/migrate.htm", title: "Migration Considerations" },
                  { url: "relnotes/doc.htm", title: "Documentation and Other Online Information" },
                  { url: "relnotes/priorrel.htm", title: "Previous Release Notes" },
              ]
            },
            { url: "concepts/wcpoconc.htm", title: "Concepts and Facilities",
              tree: [
                  { url: "concepts/wcpoarch.htm", title: "Architecture" },
                  { url: "concepts/wcpocomp.htm", title: "Components" },
                  { url: "concepts/wcpopart.htm", title: "Understanding Partitioning" },
                  { url: "concepts/wcpofilt.htm", title: "Understanding Filtering" },
                  { url: "concepts/wcpoc_go.htm", title: "Getting Started" },
              ]
            },
            { url: "planning/pg_over.htm", title: "Planning for Entire Net-Work 7",
              tree: [
                  { url: "planning/pg_gen.htm", title: "General Information" },
                  { url: "planning/pg75migr.htm", title: "Migrating to this Entire Net-Work Version" },
                  { url: "planning/pg_steps.htm", title: "Planning Steps for Entire Net-Work 7" },
                  { url: "planning/pgarch72.htm", title: "Architectural Changes Introduced in Entire Net-Work 7.2" },
                  { url: "planning/pg_faq.htm", title: "Frequently Asked Questions for Entire Net-Work 7" },
              ]
            },
            { url: "install/wcpoinst.htm", title: "Installation",
              tree: [
                  { url: "install/sslrand.htm", title: "SSL Random File Requirements on Linux Systems" },
                  { url: "install/wcpoport.htm", title: "Port Number Reference" },
              ]
            },
            { url: "admin/wcpoadm.htm", title: "Administration",
              tree: [
                  { url: "admin/wcposmh.htm", title: "About the Adabas Manager" },
                  { url: "admin/wcpoport.htm", title: "Port Number Reference" },
                  { url: "admin/wcposhrl.htm", title: "Directing Log Files to a Shared Server" },
                  { url: "admin/wcpconfig.htm", title: "Entire Net-Work Configuration Parameters" },
                  { url: "admin/wcpadmin.htm", title: "Entire Net-Work Service Function Utility (wcpadmin)" },
                  { url: "admin/adiutil.htm", title: "Entire Net-Work Utility Functions for the Directory Server (checkadi and setadi)" },
              ]
            },
            { url: "user/use-over.htm", title: "Using Adabas Manager",
              tree: [
                  { url: "user/amn-start.htm", title: "Starting and Ending an Adabas Manager Session" },
                  { url: "user/aboutui.htm", title: "The Adabas Manager Graphical User Interface" },
                  { url: "user/DatabaseAdministrationMF.htm", title: "Database Administration on Mainframe" },
                  { url: "user/NetWork.htm", title: "Entire Net-Work Administration" },
                  { url: "user/AdaAudit.htm", title: "Adabas Auditing" },
              ]
            },
            { url: "wcl/wcl.htm", title: "Entire Net-Work Client Installation and Administration",
              tree: [
                  { url: "wcl/conv.htm", title: "Conventions" },
                  { url: "wcl/wclov.htm", title: "Concepts" },
                  { url: "wcl/installwcl.htm", title: "Installing and Uninstalling Entire Net-Work Client" },
                  { url: "wcl/wcli_svc.htm", title: "Starting and Stopping Entire Net-Work Client" },
                  { url: "wcl/wcla_ov.htm", title: "Entire Net-Work Client Administration" },
                  { url: "wcl/wcposhrl.htm", title: "Directing Log Files to a Shared Server" },
                  { url: "wcl/wcpoport.htm", title: "Port Number Reference" },
                  { url: "wcl/wcpconfig.htm", title: "Entire Net-Work Configuration Parameters" },
              ]
            },
            { url: "wcpsrv/wcpsrv.htm", title: "Entire Net-Work Server Installation and Administration",
              tree: [
                  { url: "wcpsrv/conv.htm", title: "Conventions" },
                  { url: "wcpsrv/installwcpsrv.htm", title: "Installing and Uninstalling Entire Net-Work Server" },
                  { url: "wcpsrv/wcpi_svc.htm", title: "Starting and Stopping Entire Net-Work Server" },
                  { url: "wcpsrv/wcpa_ov.htm", title: "Entire Net-Work Server Administration",
                    tree: [
                        { url: "wcpsrv/wcpasrv.htm", title: "Managing Entire Net-Work Servers" },
                        { url: "wcpsrv/srvlist.htm", title: "Listing, Selecting, and Reviewing Installed Entire Net-Work Server" },
                        { url: "wcpsrv/srvaddk.htm", title: "Adding Kernel Configuration Definitions" },
                        { url: "wcpsrv/krnamigr.htm", title: "Migrating Kernel Configurations" },
                        { url: "wcpsrv/srvaparm.htm", title: "Setting Entire Net-Work Server Parameters" },
                        { url: "wcpsrv/srvtrlev.htm", title: "Setting the Trace Level for an Entire Net-Work Server" },
                        { url: "wcpsrv/srva_log.htm", title: "Managing Entire Net-Work Server Log Files" },
                        { url: "wcpsrv/srvds.htm", title: "Changing the Adabas Directory Server" },
                        { url: "wcpsrv/srvstop.htm", title: "Shutting Down the Entire Net-Work Server" },
                        { url: "wcpsrv/wcpakern.htm", title: "Managing Kernels" },
                        { url: "wcpsrv/krnlist.htm", title: "Listing, Selecting, and Reviewing Kernel Definitions" },
                        { url: "wcpsrv/krnparm.htm", title: "Reviewing the Kernel Parameter Summary" },
                        { url: "wcpsrv/krnstart.htm", title: "Starting a Kernel" },
                        { url: "wcpsrv/krnstop.htm", title: "Shutting Down a Kernel" },
                        { url: "wcpsrv/krndel.htm", title: "Deleting a Kernel" },
                        { url: "wcpsrv/krnbasic.htm", title: "Setting Basic Kernel Parameters" },
                        { url: "wcpsrv/krnadv.htm", title: "Setting Advanced Kernel Parameters" },
                        { url: "wcpsrv/krnscale.htm", title: "Specifying Kernel Scalability" },
                        { url: "wcpsrv/krnfilt.htm", title: "Maintaining Kernel Filters" },
                        { url: "wcpsrv/krnds.htm", title: "Changing the Adabas Directory Server" },
                        { url: "wcpsrv/krnacc.htm", title: "Maintaining Access Definitions" },
                        { url: "wcpsrv/krnaccst.htm", title: "Reviewing Kernel Access Status" },
                        { url: "wcpsrv/krnconn.htm", title: "Maintaining Connection Definitions" },
                        { url: "wcpsrv/krnconns.htm", title: "Reviewing Kernel Outgoing Connection Status" },
                        { url: "wcpsrv/krnstat.htm", title: "Reviewing Kernel Statistics" },
                        { url: "wcpsrv/setkstat.htm", title: "Dynamically Collecting Detailed Statistics" },
                        { url: "wcpsrv/krndump.htm", title: "Generate a Kernel Configuration Dump" },
                        { url: "wcpsrv/krncheck.htm", title: "Checking Kernel Databases" },
                        { url: "wcpsrv/krnping.htm", title: "Pinging Databases and Classic Nodes" },
                        { url: "wcpsrv/krndync.htm", title: "Dynamically Connecting and Disconnecting a Connection" },
                        { url: "wcpsrv/krnaclnt.htm", title: "Dynamically Managing Kernel Clients and Adabas Contexts" },
                        { url: "wcpsrv/krnahost.htm", title: "Dynamically Managing Kernel Client Hosts" },
                        { url: "wcpsrv/krnstatus.htm", title: "Reviewing Kernel Status" },
                        { url: "wcpsrv/krna_log.htm", title: "Managing Kernel Log Files" },
                        { url: "wcpsrv/krntrace.htm", title: "Tracing Kernel Processing" },
                        { url: "wcpsrv/wcpadmin.htm", title: "Entire Net-Work Service Function Utility (wcpadmin)" },
                        { url: "wcpsrv/wcpoport.htm", title: "Port Number Reference" },
                    ]
                  },
                  { url: "wcpsrv/adiutil.htm", title: "Entire Net-Work Utility Functions for the Directory Server (checkadi and setadi)" },
              ]
            },
            { url: "messages/wcpomsgs.htm", title: "Messages and Codes Reference",
              tree: [
                  { url: "messages/nucresp.htm", title: "Adabas Response Codes" },
                  { url: "messages/wcpomsg.htm", title: "Entire Net-Work LUW Messages" },
                  { url: "messages/tsmsgs.htm", title: "XTS* - Software AG Internal Transport Subsystem Messages" },
              ]
            },
            { url: "wsl/wsl_luw.htm", title: "Using Encryption for Entire Net-Work",
              tree: [
                  { url: "wsl/conv.htm", title: "Conventions" },
                  { url: "wsl/wsl_reln.htm", title: "Release Notes" },
                  { url: "wsl/wsl_conc.htm", title: "Concepts" },
                  { url: "wsl/wsl_inst.htm", title: "Installing Encryption for Entire Net-Work" },
                  { url: "wsl/wsl_act.htm", title: "Activating Encryption for Entire Net-Work" },
                  { url: "wsl/wsl_tool.htm", title: "Using the SSL Toolkit" },
                  { url: "wsl/wsl_def.htm", title: "Access and Connection Definition Setup" },
                  { url: "wsl/wsl_ex.htm", title: "Sample Security Scenarios" },
              ]
            },
            { url: "general/glossary.htm", title: "Glossary" },
            { url: "general/legal.htm", title: "Copyright" },
        ]
};

var mainProject = 1;

$.event.trigger({ type: "fishidbloaded", db: entirenetwork });

==> wcpos-7.9.4-en-download.zip: wcpos-7.9.4-en/webhelp/wcpos-webhelp/navig/contents.js <==
//
//	FindinSite-CD-JS-HelpIndex database entirenetwork
//
//	Copyright (c) 2016-2025 Software AG, Darmstadt, Germany and/or Software AG USA Inc., Reston, VA, USA
//
var entirenetwork = {
    baseurls: ["../"],
    varname: "entirenetwork",
        tree: [
            { url: "about/about.htm", title: "About this Documentation",
              tree: [
                  { url: "about/document_conventions.htm", title: "Document Conventions" },
                  { url: "about/online_information.htm", title: "Online Information and Support" },
                  { url: "about/data_protection.htm", title: "Data Protection" },
              ]
            },
            { url: "relnotes/wcporeln.htm", title: "Entire Net-Work 7.9 Release Notes",
              tree: [
                  { url: "relnotes/enhance.htm", title: "Enhancements" },
                  { url: "relnotes/wcprcomp.htm", title: "Entire Net-Work 7 Compatibility" },
                  { url: "relnotes/endofmaint.htm", title: "End of Maintenance" },
                  { url: "relnotes/migrate.htm", title: "Migration Considerations" },
              ]
            },
            { url: "concepts/wcpoconc.htm", title: "Concepts and Facilities",
              tree: [
                  { url: "concepts/wcpoarch.htm", title: "Architecture" },
                  { url: "concepts/wcpocomp.htm", title: "Components" },
                  { url: "concepts/wcpopart.htm", title: "Understanding Partitioning" },
                  { url: "concepts/wcpofilt.htm", title: "Understanding Filtering" },
                  { url: "concepts/wcpoc_go.htm", title: "Getting Started" },
              ]
            },
            { url: "planning/pg_over.htm", title: "Planning for Entire Net-Work 7",
              tree: [
                  { url: "planning/pg_gen.htm", title: "General Information" },
                  { url: "planning/pg75migr.htm", title: "Migrating to this Entire Net-Work Version" },
                  { url: "planning/pg_steps.htm", title: "Planning Steps for Entire Net-Work 7" },
                  { url: "planning/pgarch72.htm", title: "Architectural Changes Introduced in Entire Net-Work 7.2" },
                  { url: "planning/pg_faq.htm", title: "Frequently Asked Questions for Entire Net-Work 7" },
              ]
            },
            { url: "install/wcpoinst.htm", title: "Installation",
              tree: [
                  { url: "install/sslrand.htm", title: "SSL Random File Requirements on Linux Systems" },
                  { url: "install/wcpoport.htm", title: "Port Number Reference" },
              ]
            },
            { url: "admin/wcpoadm.htm", title: "Administration",
              tree: [
                  { url: "admin/wcposmh.htm", title: "About the Adabas Manager" },
                  { url: "admin/wcpoport.htm", title: "Port Number Reference" },
                  { url: "admin/wcposhrl.htm", title: "Directing Log Files to a Shared Server" },
                  { url: "admin/wcpconfig.htm", title: "Entire Net-Work Configuration Parameters" },
                  { url: "admin/wcpadmin.htm", title: "Entire Net-Work Service Function Utility (wcpadmin)" },
                  { url: "admin/adiutil.htm", title: "Entire Net-Work Utility Functions for the Directory Server (checkadi and setadi)" },
              ]
            },
            { url: "user/use-over.htm", title: "Using Adabas Manager",
              tree: [
                  { url: "user/amn-start.htm", title: "Starting and Ending an Adabas Manager Session" },
                  { url: "user/amn-usage.htm", title: "Common Usage Scenarios on Linux and Windows" },
                  { url: "user/DatabaseAdministrationMF.htm", title: "Database Administration on Mainframe" },
                  { url: "user/NetWork.htm", title: "Entire Net-Work Administration" },
                  { url: "user/AdaAudit.htm", title: "Adabas Auditing" },
                  { url: "user/target_adapter.htm", title: "Event Replicator Target Adapter (Target Adapter)" },
              ]
            },
            { url: "wcl/wcl.htm", title: "Entire Net-Work Client Installation and Administration",
              tree: [
                  { url: "wcl/conv.htm", title: "Conventions" },
                  { url: "wcl/wclov.htm", title: "Concepts" },
                  { url: "wcl/installwcl.htm", title: "Installing and Uninstalling Entire Net-Work Client" },
                  { url: "wcl/wcli_svc.htm", title: "Starting and Stopping Entire Net-Work Client" },
                  { url: "wcl/wcla_ov.htm", title: "Entire Net-Work Client Administration" },
                  { url: "wcl/wcposhrl.htm", title: "Directing Log Files to a Shared Server" },
                  { url: "wcl/wcpoport.htm", title: "Port Number Reference" },
                  { url: "wcl/wcpconfig.htm", title: "Entire Net-Work Configuration Parameters" },
              ]
            },
            { url: "wcpsrv/wcpsrv.htm", title: "Entire Net-Work Server Installation and Administration",
              tree: [
                  { url: "wcpsrv/conv.htm", title: "Conventions" },
                  { url: "wcpsrv/installwcpsrv.htm", title: "Installing and Uninstalling Entire Net-Work Server" },
                  { url: "wcpsrv/wcpi_svc.htm", title: "Starting and Stopping Entire Net-Work Server" },
                  { url: "wcpsrv/wcpa_ov.htm", title: "Entire Net-Work Server Administration",
                    tree: [
                        { url: "wcpsrv/wcpasrv.htm", title: "Managing Entire Net-Work Servers" },
                        { url: "wcpsrv/srvlist.htm", title: "Listing, Selecting, and Reviewing Installed Entire Net-Work Server" },
                        { url: "wcpsrv/srvaddk.htm", title: "Adding Kernel Configuration Definitions" },
                        { url: "wcpsrv/krnamigr.htm", title: "Migrating Kernel Configurations" },
                        { url: "wcpsrv/srvaparm.htm", title: "Setting Entire Net-Work Server Parameters" },
                        { url: "wcpsrv/srvtrlev.htm", title: "Setting the Trace Level for an Entire Net-Work Server" },
                        { url: "wcpsrv/srva_log.htm", title: "Managing Entire Net-Work Server Log Files" },
                        { url: "wcpsrv/srvds.htm", title: "Changing the Adabas Directory Server" },
                        { url: "wcpsrv/srvstop.htm", title: "Shutting Down the Entire Net-Work Server" },
                        { url: "wcpsrv/wcpakern.htm", title: "Managing Kernels" },
                        { url: "wcpsrv/krnlist.htm", title: "Listing, Selecting, and Reviewing Kernel Definitions" },
                        { url: "wcpsrv/krnparm.htm", title: "Reviewing the Kernel Parameter Summary" },
                        { url: "wcpsrv/krnstart.htm", title: "Starting a Kernel" },
                        { url: "wcpsrv/krnstop.htm", title: "Shutting Down a Kernel" },
                        { url: "wcpsrv/krndel.htm", title: "Deleting a Kernel" },
                        { url: "wcpsrv/krnbasic.htm", title: "Setting Basic Kernel Parameters" },
                        { url: "wcpsrv/krnadv.htm", title: "Setting Advanced Kernel Parameters" },
                        { url: "wcpsrv/krnscale.htm", title: "Specifying Kernel Scalability" },
                        { url: "wcpsrv/krnfilt.htm", title: "Maintaining Kernel Filters" },
                        { url: "wcpsrv/krnds.htm", title: "Changing the Adabas Directory Server" },
                        { url: "wcpsrv/krnacc.htm", title: "Maintaining Access Definitions" },
                        { url: "wcpsrv/krnaccst.htm", title: "Reviewing Kernel Access Status" },
                        { url: "wcpsrv/krnconn.htm", title: "Maintaining Connection Definitions" },
                        { url: "wcpsrv/krnconns.htm", title: "Reviewing Kernel Outgoing Connection Status" },
                        { url: "wcpsrv/krnstat.htm", title: "Reviewing Kernel Statistics" },
                        { url: "wcpsrv/setkstat.htm", title: "Dynamically Collecting Detailed Statistics" },
                        { url: "wcpsrv/krndump.htm", title: "Generate a Kernel Configuration Dump" },
                        { url: "wcpsrv/krncheck.htm", title: "Checking Kernel Databases" },
                        { url: "wcpsrv/krnping.htm", title: "Pinging Databases and Classic Nodes" },
                        { url: "wcpsrv/krndync.htm", title: "Dynamically Connecting and Disconnecting a Connection" },
                        { url: "wcpsrv/krnaclnt.htm", title: "Dynamically Managing Kernel Clients and Adabas Contexts" },
                        { url: "wcpsrv/krnahost.htm", title: "Dynamically Managing Kernel Client Hosts" },
                        { url: "wcpsrv/krnstatus.htm", title: "Reviewing Kernel Status" },
                        { url: "wcpsrv/krna_log.htm", title: "Managing Kernel Log Files" },
                        { url: "wcpsrv/krntrace.htm", title: "Tracing Kernel Processing" },
                        { url: "wcpsrv/wcpadmin.htm", title: "Entire Net-Work Service Function Utility (wcpadmin)" },
                        { url: "wcpsrv/wcpoport.htm", title: "Port Number Reference" },
                    ]
                  },
                  { url: "wcpsrv/adiutil.htm", title: "Entire Net-Work Utility Functions for the Directory Server (checkadi and setadi)" },
              ]
            },
            { url: "messages/wcpomsgs.htm", title: "Messages and Codes Reference",
              tree: [
                  { url: "messages/nucresp.htm", title: "Adabas Response Codes" },
                  { url: "messages/wcpomsg.htm", title: "Entire Net-Work LUW Messages" },
                  { url: "messages/tsmsgs.htm", title: "XTS* - internal Transport Subsystem Messages" },
              ]
            },
            { url: "wsl/wsl_luw.htm", title: "Using Encryption for Entire Net-Work",
              tree: [
                  { url: "wsl/conv.htm", title: "Conventions" },
                  { url: "wsl/wsl_reln.htm", title: "Release Notes" },
                  { url: "wsl/wsl_conc.htm", title: "Concepts" },
                  { url: "wsl/wsl_inst.htm", title: "Installing Encryption for Entire Net-Work" },
                  { url: "wsl/wsl_act.htm", title: "Activating Encryption for Entire Net-Work" },
                  { url: "wsl/wsl_tool.htm", title: "Using the SSL Toolkit" },
                  { url: "wsl/wsl_def.htm", title: "Access and Connection Definition Setup" },
                  { url: "wsl/wsl_ex.htm", title: "Sample Security Scenarios" },
              ]
            },
            { url: "general/glossary.htm", title: "Glossary" },
            { url: "general/legal.htm", title: "Copyright" },
        ]
};

var mainProject = 1;

$.event.trigger({ type: "fishidbloaded", db: entirenetwork });
